2.7. Loading Feature Additional Info — machado 0.1.0 documentation

# 2.7. Loading Feature Additional Info

Please notice the features must be loaded in advance. If the annotation or sequence was loaded previously, it will be replaced.

## 2.7.1. Load Annotation

    python manage.py load_feature_annotation --file feature_annotation.tab --soterm polypeptide --cvterm display

- Loading this file can be faster if you increase the number of threads (–cpu).

    python manage.py load_feature_annotation --help

–file | Two-column tab separated file (feature.accession<TAB>annotation text). *
–soterm | SO Sequence Ontology Term (eg. mRNA, polypeptide) *
–cvterm | cvterm.name from cv feature_property. (eg. display, note, product, alias, ontology_term) *
–cpu | Number of threads

* required fields

## 2.7.2. Remove Annotation

If, by any reason, you need to remove a feature annotation you should use the command remove_feature_annotation.

    python manage.py remove_feature_annotation --help

## 2.7.3. Load Sequence

    python manage.py load_feature_sequence --file Athaliana_transcripts.fasta --soterm mRNA

- Loading this file can be faster if you increase the number of threads (–cpu).

    python manage.py load_feature_sequence --help

–file | FASTA file. *
–soterm | SO Sequence Ontology Term (eg. chromosome, assembly, mRNA, polypeptide) *
–cpu | Number of threads

* required fields

## 2.7.4. Remove Sequence

If, by any reason, you need to remove a feature sequence you should use the command load_feature_sequence itself and provide a FASTA file with no sequence. For example:

    >chr1

    >chr2

## 2.7.5. Load Publication

    python manage.py load_feature_publication --file feature_publication.tab

- Loading this file can be faster if you increase the number of threads (–cpu).

    python manage.py load_feature_publication --help

–file | Two-column tab separated file (feature.accession<TAB>DOI). *
–cpu | Number of threads

* required fields

## 2.7.6. Remove Publication

If, by any reason, you need to remove a feature publication attribution, you should use the command remove_publication.

    python manage.py remove_publication --help

## 2.7.7. Load DBxRef

    python manage.py load_feature_dbxrefs --file feature_dbxrefs.tab --soterm mRNA

- Loading this file can be faster if you increase the number of threads (–cpu).

    python manage.py load_feature_dbxrefs --help

–file | Two-column tab separated file (feature.accession<TAB>db:dbxref). *
–soterm | SOTERM SO Sequence Ontology Term (eg. chromosome, assembly, mRNA, polypeptide) *
–cpu | Number of threads

* required fields